@@ -198,7 +198,7 @@ namespace FSpot.Mrw {
 
 		public override System.IO.Stream PixbufStream ()
 		{
-			return null;
+			return DCRawFile.RawPixbufStream (path);
 		}
 		
 		public override Gdk.Pixbuf Load ()
@@ -220,7 +220,7 @@ namespace FSpot.Mrw {
 						if (b is TtwBlock) {
 							TtwBlock ttw = (TtwBlock) b;
 							Header = ttw.TiffHeader;
-							Header.Dump ("TTW:");
+							//Header.Dump ("TTW:");
 							break;
 						}
 					}
