@@ -123,6 +123,9 @@ public class Photo : DbItem, IComparable, FSpot.IBrowsableItem {
 		get {
 			return time;
 		}
+		set {
+			time = value;
+		}
 	}
 
 	private string directory_path;
@@ -451,7 +454,7 @@ public class Photo : DbItem, IComparable, FSpot.IBrowsableItem {
 			FSpot.JpegFile jimg = img as FSpot.JpegFile;
 			
 			jimg.SetDescription (this.Description);
-		
+			jimg.SetDateTimeOriginal (this.Time);
 			FSpot.Xmp.XmpFile xmp = CreateXmp (this);
 			jimg.SetXmp (xmp);
 
@@ -988,8 +991,25 @@ public class PhotoStore : DbStore {
 
 	public override void Commit (DbItem item)
 	{
-		Photo photo = item as Photo;
+		DbItemEventArgs args = new DbItemEventArgs (item);
+		Commit (args.Items, args);
+	}
 
+	public void Commit (DbItem [] items, DbItemEventArgs args)
+	{
+		if (items.Length > 1)
+			BeginTransaction ();
+
+		foreach (DbItem item in items) {
+			Update ((Photo)item);
+		}
+		EmitChanged (items, args);
+
+		if (items.Length > 1)
+			CommitTransaction ();
+	}
+	
+        private void Update (Photo photo) {
 		// Update photo.
 
 		SqliteCommand command = new SqliteCommand ();
@@ -1043,8 +1063,6 @@ public class PhotoStore : DbStore {
 			command.ExecuteNonQuery ();
 			command.Dispose ();
 		}
-
-		EmitChanged (item);
 	}
 	
 	public class DateRange 
@@ -1143,13 +1161,20 @@ public class PhotoStore : DbStore {
 		return Query (query_string);
 	}
 
-	public Photo [] QueryUntagged ()
+	public Photo [] QueryUntagged (DateRange range)
 	{
 		StringBuilder query_builder = new StringBuilder ();
 
 		query_builder.Append ("SELECT * FROM photos WHERE id NOT IN " +
-					"(SELECT DISTINCT photo_id FROM photo_tags) " +
-					"ORDER BY time");
+					"(SELECT DISTINCT photo_id FROM photo_tags) ");
+		
+		if (range != null) {
+			query_builder.Append (String.Format ("AND photos.time >= {0} AND photos.time < {1} ",
+							     DbUtils.UnixTimeFromDateTime (range.Start), 
+							     DbUtils.UnixTimeFromDateTime (range.End)));
+		}
+
+		query_builder.Append("ORDER BY time");
 
 		return Query (query_builder.ToString ());
 	}
