@@ -324,16 +324,8 @@ public class PhotoView : EventBox {
 	{
 		if (description_delay.IsPending) {
 			description_delay.Stop ();
-
-#if true // UPDATE_EXIF_DESCRIPTION
 			Photo photo = query.Photos [description_photo];
-
-			photo.WriteMetadataToImage ();
-
 			Query.Commit (description_photo);
-#else
-			Query.Commit (description_photo);
-#endif
 		}
 		return true;
 	}
@@ -429,8 +421,10 @@ public class PhotoView : EventBox {
 		HBox inner_hbox = new HBox (false, 2);
 		//inner_hbox.BorderWidth = 6;
 
-		tag_view = new TagView ();
-		inner_hbox.PackStart (tag_view, false, true, 0);
+		EventBox tag_view_box = new EventBox ();
+		tag_view = new TagView (tag_view_box);
+		tag_view_box.Add (tag_view);
+		inner_hbox.PackStart (tag_view_box, false, true, 0);
 
 		description_entry = new Entry ();
 		inner_hbox.PackStart (description_entry, true, true, 0);
